current_func_name

Function current_func_name 

pub fn current_func_name() -> String
Returns the name of the currently executing function (top of FUNC_NAME_STACK).

Returns an empty string when executing at the top level (REPL / script scope).