pub fn format_scalar(n: f64, base: Base, mode: &FormatMode) -> StringExpand description
Formats a scalar f64 for user-facing output using the given base and format mode.
pub fn format_scalar(n: f64, base: Base, mode: &FormatMode) -> StringFormats a scalar f64 for user-facing output using the given base and format mode.