global_refresh_into_env

Function global_refresh_into_env 

pub fn global_refresh_into_env(env: &mut Env)
Refreshes all names declared global in the current scope from GLOBAL_ENV into env.

Called at the end of exec_stmts to ensure that modifications made to global variables inside called functions are visible to the current scope’s environment.