set_display_ctx

Function set_display_ctx 

pub fn set_display_ctx(fmt: &FormatMode, base: Base, compact: bool)
Sets the display context used when executing function bodies.

Called at the start of exec_stmts so that named functions called from within a block inherit the caller’s display settings.