pub fn set_eval_str_hook(f: EvalStrHook)Expand description
Registers the hook that executes a code string in expression context.
Must be called by exec::init() before any eval() expression-context call.
pub fn set_eval_str_hook(f: EvalStrHook)Registers the hook that executes a code string in expression context.
Must be called by exec::init() before any eval() expression-context call.