pub fn init()Expand description
Initialises exec-level hooks in eval.rs so that eval_inner can call user functions.
Must be called once at program startup before any evaluation takes place.
pub fn init()Initialises exec-level hooks in eval.rs so that eval_inner can call user functions.
Must be called once at program startup before any evaluation takes place.