pub fn session_path_add(path: PathBuf, append: bool)Expand description
Prepends (default) or appends a directory to the session search path.
If the same path is already present it is removed from its current position before being re-inserted, so the path list contains no duplicates.