is_single_line_block

Function is_single_line_block 

pub fn is_single_line_block(line: &str) -> bool
Returns true when line is a self-contained single-line block, e.g. if cond; body; end. These lines start with a block-opening keyword but also close themselves with end / until in the same line, so they do not need multi-line buffering.