pub type Env = HashMap<String, Value>;Expand description
Variable environment: maps names to values.
ans is the reserved name for the result of the last expression
that was not assigned to a named variable (Octave/MATLAB convention).
Aliased Type
pub struct Env { /* private fields */ }