Tokenizer, recursive-descent parser, and Stmt AST.
Enums
- Stmt
- Top-level statement returned by
parseandparse_stmts.
Functions
- block_
depth_ delta - Returns the net block-depth change for a single (comment-stripped, trimmed) line.
- is_
partial - Returns true if the input looks like a partial expression (i.e. starts with an operator that needs a left-hand operand).
- is_
single_ line_ block - Returns
truewhenlineis a self-contained single-line block, e.g.if cond; body; end. These lines start with a block-opening keyword but also close themselves withend/untilin the same line, so they do not need multi-line buffering. - parse
- Parses a full input string into a
Stmt. - parse_
stmts - Parses a multi-line block string into a sequence of
(Stmt, silent)pairs. - split_
stmts - Splits a raw input line into
(statement_str, silent)pairs.